@@ -14,6 +14,10 @@ class DataLayerFakt(Fakt):
 
 
 class FaktsDataLayer(DataLayer):
+    """ A fakts implementation of the datalayer. This will allow you to connect to a datalayer
+    that is defined asnychronously in fakts. This is useful for connecting to a datalayer that
+    is not known at compile time. Will get the server configuration from fakts and connect to the
+    datalayer. """
     fakts_group: str
     fakts: Optional[Fakts] = None
     herre: Optional[Herre] = None
